From 5ae20d50ea501033b4e7ca684bfab081a97cc398 Mon Sep 17 00:00:00 2001
From: timothycarambat <rambat1010@gmail.com>
Date: Sat, 27 Apr 2024 12:39:45 -0700
Subject: [PATCH] patch agent invocation regression resolves #1211

---
 server/models/workspaceAgentInvocation.js | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/server/models/workspaceAgentInvocation.js b/server/models/workspaceAgentInvocation.js
index 4ef56e40e..b00833754 100644
--- a/server/models/workspaceAgentInvocation.js
+++ b/server/models/workspaceAgentInvocation.js
@@ -3,9 +3,9 @@ const { v4: uuidv4 } = require("uuid");
 
 const WorkspaceAgentInvocation = {
   // returns array of strings with their @ handle.
   // must start with @
   parseAgents: function (promptString) {
-    if (!promptString.startsWith("@")) return [];
+    if (!promptString.startsWith("@agent")) return [];
     return promptString.split(/\s+/).filter((v) => v.startsWith("@"));
   },
 
@@ -3,9 +3,9 @@ const { v4: uuidv4 } = require("uuid");
 const WorkspaceAgentInvocation = {
   // returns array of strings with their @ handle.
-  // must start with @
+  // must start with @agent for now.
   parseAgents: function (promptString) {
-- 
GitLab